@@ -16,9 +16,9 @@ use Catalyst;
 use Catalyst::Request::REST;
 use Catalyst::Controller::REST;
 
-use 5.8.1;
+BEGIN { require 5.008001; }
 
-our $VERSION = '0.65';
+our $VERSION = '0.66';
 
 # This is wrong in several ways. First, there's no guarantee that
 # Catalyst.pm has not been subclassed. Two, there's no guarantee that
